@@ -1,6 +1,6 @@
 #!/usr/bin/env python
-import glob
 import os
+import sys
 import subprocess
 import shutil
 
@@ -11,7 +11,8 @@ if os.path.exists(vedir):
     shutil.rmtree(vedir)
 
 virtualenv_support_dir = os.path.abspath(
-    os.path.join(pwd, "requirements", "virtualenv_support"))
+    os.path.join(
+        pwd, "requirements", "virtualenv_support"))
 
 ret = subprocess.call(["python", "virtualenv.py",
                        "--extra-search-dir=%s" % virtualenv_support_dir,
@@ -20,27 +21,25 @@ ret = subprocess.call(["python", "virtualenv.py",
 if ret:
     exit(ret)
 
-ret = subprocess.call([os.path.join(vedir, 'bin', 'pip'), "install",
-                       "-E", vedir,
-                       "--index-url=''",
-                       "--requirement",
-                       os.path.join(pwd, "requirements/apps.txt")])
+if sys.version.startswith('2.6'):
+    # have to do seperately or it breaks in 2.7
+    ret = subprocess.call(
+        [os.path.join(vedir, 'bin', 'pip'), "install",
+         "-E", vedir,
+         "--index-url=''",
+         os.path.join(pwd, "requirements/src/importlib-1.0.1.tar.gz")])
+    if ret:
+        exit(ret)
+
+ret = subprocess.call(
+    [os.path.join(vedir, 'bin', 'pip'), "install",
+     "-E", vedir,
+     "--index-url=''",
+     "--requirement",
+     os.path.join(pwd, "requirements/apps.txt")])
 if ret:
     exit(ret)
 
-
-def has_eggs():
-    return [os.path.basename(path) for path in
-            glob.glob(os.path.join(pwd, "requirements", "eggs", "*.egg"))]
-
-if has_eggs():
-    # only try to easy install eggs if there actually are some
-    cmd = ([os.path.join(vedir, "bin/easy_install"),
-            '-f', os.path.join(pwd, "requirements/eggs/")] +
-           has_eggs())
-    ret = subprocess.call(cmd)
-    exit(ret)
-
 ret = subprocess.call(["python", "virtualenv.py", "--relocatable", vedir])
 # --relocatable always complains about activate.csh, which we don't really
 # care about. but it means we need to ignore its error messages
