@@ -313,7 +313,8 @@ class Checker(object):
 
     # "expr" type nodes
     BOOLOP = BINOP = UNARYOP = IFEXP = DICT = SET = YIELD = COMPARE = \
-    CALL = REPR = ATTRIBUTE = SUBSCRIPT = LIST = TUPLE = handleChildren
+        CALL = REPR = ATTRIBUTE = SUBSCRIPT = LIST = TUPLE = TRY = \
+        WITHITEM = handleChildren
 
     NUM = STR = ELLIPSIS = ignore
 
@@ -325,8 +326,8 @@ class Checker(object):
 
     # same for operators
     AND = OR = ADD = SUB = MULT = DIV = MOD = POW = LSHIFT = RSHIFT = \
-    BITOR = BITXOR = BITAND = FLOORDIV = INVERT = NOT = UADD = USUB = \
-    EQ = NOTEQ = LT = LTE = GT = GTE = IS = ISNOT = IN = NOTIN = ignore
+        BITOR = BITXOR = BITAND = FLOORDIV = INVERT = NOT = UADD = USUB = \
+        EQ = NOTEQ = LT = LTE = GT = GTE = IS = ISNOT = IN = NOTIN = ignore
 
     # additional node types
     COMPREHENSION = KEYWORD = handleChildren
@@ -336,6 +337,9 @@ class Checker(object):
         if node.name is not None:
             if isinstance(node.name, str):
                 name = node.name
+            elif hasattr(node.name, 'elts'):
+                names = [e.id for e in node.name.elts]
+                name = '({0})'.format(', '.join(names))
             else:
                 name = node.name.id
             self.addBinding(node.lineno, Assignment(name, node))
@@ -366,7 +370,7 @@ class Checker(object):
                 existing = scope.get(value.name)
                 if (isinstance(existing, Importation)
                         and not existing.used
-                        and (not isinstance(value, Importation) \
+                        and (not isinstance(value, Importation)
                              or value.fullName == existing.fullName)
                         and reportRedef):
                     self.report(messages.RedefinedWhileUnused,
@@ -646,21 +650,21 @@ class Checker(object):
             self.addBinding(node.lineno, importation)
 
 
-def checkPath(filename):
+def checkPath(filename, ignore=[]):
     """
     Check the given path, printing out any warnings detected.
 
     @return: the number of warnings printed
     """
     try:
-        return check(open(filename, 'U').read() + '\n', filename)
+        return check(open(filename, 'U').read() + '\n', ignore, filename)
     except IOError:
         msg = sys.exc_info()[1]
         sys.stderr.write("%s: %s\n" % (filename, msg.args[1]))
         return 1
 
 
-def check(codeString, filename='(code)'):
+def check(codeString, ignore, filename='stdin'):
     """
     Check the Python source given by C{codeString} for flakes.
 
@@ -711,7 +715,7 @@ def check(codeString, filename='(code)'):
         valid_warnings = 0
 
         for warning in w.messages:
-            if skip_warning(warning):
+            if skip_warning(warning, ignore):
                 continue
             print(warning)
             valid_warnings += 1
